@@ -22,8 +22,6 @@
 
 #include "worldscene.h"
 
-#include "worldscene.moc"
-
 #include "settings.h"
 
 #include "arrow.h"
@@ -38,24 +36,17 @@
 
 #include <QGraphicsItem>
 #include <QGraphicsSceneMouseEvent>
-#include <QKeyEvent>
 #include <QItemSelectionModel>
 #include <QPainter>
-#include <QAction>
 #include <QToolTip>
-#include <QLabel>
 #include <QTimer>
 #include <QScrollBar>
-#include <QSignalMapper>
-#include <QToolButton>
-#include <QHBoxLayout>
-#include <QVBoxLayout>
 #include <QGLWidget>
 #include <QWheelEvent>
 #include <QCoreApplication>
-#include <KIcon>
-#include <KUrl>
-#include <KLocale>
+#include <QUrl>
+
+#include <KLocalizedString>
 #include <KDebug>
 
 class WorldSceneAxes: public QGraphicsItem
@@ -77,11 +68,13 @@ protected:
 };
 
 WorldSceneAxes::WorldSceneAxes(QGraphicsItem* parent, QGraphicsScene* scene)
-    : QGraphicsItem(parent, scene),
+    : QGraphicsItem(parent),
     _boundingRect(-LENGTH, -LENGTH, LENGTH+LENGTH, LENGTH+LENGTH)
 {
     _viewScale = 1;
     setZValue(-100);
+    if (scene)
+      scene->addItem(this);
 }
 
 QRectF WorldSceneAxes::boundingRect() const
@@ -432,7 +425,7 @@ QRectF WorldScene::calcItemsBoundingRect()
 
 void WorldScene::messageLinkActivated(const QString& link)
 {
-    emit linkActivated(link);
+    emit linkActivated(QUrl::fromUserInput(link));
 }
 
 void WorldScene::settingsChanged()
